Learn R Programming

LSX (version 1.5.1)

as.seedwords: Convert a list or a dictionary to seed words

Description

Convert a list or a dictionary to seed words

Usage

as.seedwords(x, upper = 1, lower = 2, concatenator = "_")

Value

named numeric vector for seed words with polarity scores

Arguments

x

a list of characters vectors or a dictionary object.

upper

numeric index or key for seed words for higher scores.

lower

numeric index or key for seed words for lower scores.

concatenator

character to replace separators of multi-word seed words.